interface SDKConfig {
    /**
     * @description Hostname of the hosted Analyzee server
     * @default 'api.analyzee.io'
     */
    host?: string;
    /**
     * @description Establish connection over secure protocol
     * @default true
     */
    secure?: boolean;
    /**
     * @description Start in verbose mode (Debug messages are printed to console)
     * @default false
     */
    verbose?: boolean;
    /**
     * @description Analyzee Project ID
     */
    project?: string;
    /**
     * @description Protocol used for establishing connection
     */
    protocol?: 'http' | 'https';
    services?: {
        /**
         * @description CDN used for downloading services
         * @default https://cdn.jsdelivr.net/npm/@analyzee/sdk@latest
         */
        cdn?: string;
        sessions?: {
            /**
             * @description Enable sessions service
             * @type boolean
             * @default false
             */
            enabled?: boolean;
            /**
             * @description Toggle collecting fonts from the website
             * @type boolean
             * @default true
             */
            collectFonts?: boolean;
            /**
             * @description Flag indicating should canvas elements be recorded
             * @type boolean
             * @default true
             */
            recordCanvas?: boolean;
            /**
             * @description Flag indicating should network requests be recorded
             * @type boolean
             * @default true
             */
            recordNetwork?: boolean;
            /**
             * @description Toggle all input masking with boolean or dictionary of elements to mask
             * @type boolean | Dictionary<string, boolean>
             * @default true
             */
            maskInputs?: boolean | {
                color?: boolean;
                date?: boolean;
                "datetime-local"?: boolean;
                email?: boolean;
                month?: boolean;
                number?: boolean;
                range?: boolean;
                search?: boolean;
                tel?: boolean;
                text?: boolean;
                time?: boolean;
                url?: boolean;
                week?: boolean;
                textarea?: boolean;
                select?: boolean;
                password?: boolean;
            };
            /**
             * @description Number of milliseconds how often should script take page snapshot (DOM serialization)
             * @type number
             * @default 120000
             */
            snapshotInterval?: number;
            /**
             * @description Number of milliseconds for scroll debounce function (how often should scroll event be recorded)
             * @type number
             * @default 100
             */
            debounceScroll?: number;
            /**
             * @description Number of milliseconds for mouse move debounce function (how often should mouse move event be recorded)
             * @type number
             * @default 1
             */
            debounceMouseMove?: number;
        };
        hotLeads?: {
            /**
             * @description Enable hotLeads service
             */
            enabled?: boolean;
        };
        assist?: {
            /**
             * @description Enable assist service
             */
            enabled?: boolean;
            /**
             * @description Hostname of the hosted Assist WebSocket server
             * @default 'wss://assist.analyzee.io'
             */
            host: string;
        };
        chat?: {
            /**
             * @description Enable chat service
             */
            support?: boolean;
            /**
             * @description Force users to provide email address before starting chat so they can be contacted later
             */
            email_alert?: boolean;
            config?: {
                support?: {
                    popup?: {
                        logo?: string;
                        bg?: string;
                        color?: string;
                        greeting?: string;
                        introduction?: string;
                        button_title?: string;
                        button_subtitle?: string;
                        /**
                         * @description Email address where users can contact our customers
                         */
                        contact_email?: string;
                    };
                    launcher?: {
                        border?: boolean;
                        color?: string;
                        bg?: string;
                        hover_bg?: string;
                    };
                };
            };
        };
    };
}

declare class AnalyzeeAssist {
    /**
     * @private Analyzee instance
     */
    private _analyzee;
    /**
     * @private Options for the session replay
     */
    private _options;
    /**
     * @private Project ID
     */
    private readonly _project;
    /**
     * @private PeerJS instance
     */
    private _peer;
    /**
     * @private PeerJS instances
     */
    private _connections;
    /**
     * @private Elements to be destroyed on connection close
     */
    private _elements;
    private _closeTimeout;
    /**
     * @private Last clicked element by operator
     */
    private _lastClickedElement;
    /**
     * @private Interval instance for sending visibility state, page URL, etc
     */
    private _dataInterval;
    constructor(analyzee: Analyzee, options: SDKConfig['services']['assist'], project: string);
    destroy(): void;
    private _init;
    private _updatePeerId;
    private _sendIntervalData;
}

declare class AnalyzeeSessions {
    /**
     * @public Call this function to stop recording
     */
    _stopRecording: () => void;
    /**
     * @private Analyzee instance
     */
    private _analyzee;
    /**
     * @private Add event to the queue
     */
    private readonly _addInternalEvent;
    /**
     * @private Options for the session replay
     */
    private _config;
    /**
     * @private Interval instance for taking snapshots
     */
    private _snapshotInterval;
    constructor(analyzee: Analyzee, _addInternalEvent: Analyzee['_addInternalEvent'], config: SDKConfig['services']['sessions']);
    destroy(): void;
    /**
     * Takes a snapshot of the current page including all the DOM elements
     */
    takeSnapshot(): void;
    private _init;
}

interface FirestoreBroadcast {
    id: string;
    measurement: 'visits' | 'track';
    /**
     * @description Only required if measurement is 'track'. The name of the event to track.
     */
    event?: string;
    project: string;
    timespan: 'today' | 'week' | 'month' | 'year' | 'all';
    timespanDescription: string;
    name: string;
    page: string;
    pageMatch: 'exact' | 'startsWith' | 'endsWith' | 'contains';
    createdOn: number;
    active: boolean;
    theme: 'light' | 'dark';
    position: 'top-left' | 'top-right' | 'bottom-left' | 'bottom-right';
    suffix: string;
    description: string;
    minimum: number;
    size: 'small' | 'regular' | 'large';
    showDelay: number;
    icon: string;
}

interface AnalyzeeSDKOptions {
    /**
     * @description Start in debug mode
     * @default false
     */
    debug?: boolean;
    /**
     * @description Hostname of the hosted Analyzee server
     * @default 'api.analyzee.io'
     */
    host?: string;
    /**
     * @description CDN hostname of the hosted Analyzee server
     * @default 'cdn.analyzee.io'
     */
    cdn?: string;
    /**
     * @description CDN used for downloading services
     * @default https://cdn.jsdelivr.net/npm/@analyzee/sdk@latest
     */
    services_cdn?: string;
    /**
     * @description Protocol of the hosted Analyzee server
     * @default 'https'
     */
    protocol?: 'http' | 'https';
    /**
     * @description Analyzee Project ID
     */
    project?: string;
    /**
     * @description Session Replay configuration
     */
    sessionReplay?: {
        /**
         * @description Enable sessionReplay service
         * @type boolean
         * @default false
         */
        enabled: boolean;
        /**
         * @description Toggle collecting fonts from the website
         * @type boolean
         * @default true
         */
        collectFonts?: boolean;
        /**
         * @description Flag indicating should canvas elements be recorded
         * @type boolean
         * @default true
         */
        recordCanvas?: boolean;
        /**
         * @description Toggle all input masking with boolean or dictionary of elements to mask
         * @type boolean | Dictionary<string, boolean>
         * @default true
         */
        maskInputs?: boolean | {
            color?: boolean;
            date?: boolean;
            'datetime-local'?: boolean;
            email?: boolean;
            month?: boolean;
            number?: boolean;
            range?: boolean;
            search?: boolean;
            tel?: boolean;
            text?: boolean;
            time?: boolean;
            url?: boolean;
            week?: boolean;
            textarea?: boolean;
            select?: boolean;
            password?: boolean;
        };
        /**
         * @description Number of milliseconds how often should script take page snapshot (DOM serialization)
         * @type number
         * @default 30000
         */
        checkoutInterval?: number;
        /**
         * @description Number of milliseconds for scroll debounce function (how often should scroll event be recorded)
         * @type number
         * @default 1
         */
        debounceScroll?: number;
        /**
         * @description Number of milliseconds for mouse move debounce function (how often should mouse move event be recorded)
         * @type number
         * @default 1
         */
        debounceMouseMove?: number;
    };
    hotLeads?: {
        /**
         * @description Enable hotLeads service
         * @type boolean
         * @default false
         */
        enabled: boolean;
    };
    broadcasts?: {
        measurement: FirestoreBroadcast['measurement'];
        event: FirestoreBroadcast['event'];
        timespan: FirestoreBroadcast['timespan'];
        page: FirestoreBroadcast['page'];
        pageMatch: FirestoreBroadcast['pageMatch'];
        theme: FirestoreBroadcast['theme'];
        position: FirestoreBroadcast['position'];
        suffix: FirestoreBroadcast['suffix'];
        description: FirestoreBroadcast['description'];
        minimum: FirestoreBroadcast['minimum'];
        size: FirestoreBroadcast['size'];
        showDelay: FirestoreBroadcast['showDelay'];
    }[];
    assist?: {
        /**
         * @description Hostname of the hosted Assist WebSocket server
         * @default 'wss://assist.analyzee.io'
         */
        host: string;
    };
    chat?: {
        /**
         * @description Enable chat service
         */
        support?: boolean;
        direct?: boolean;
        email_alert?: boolean;
        config?: {
            support?: {
                popup?: {
                    logo?: string;
                    bg?: string;
                    color?: string;
                    greeting?: string;
                    introduction?: string;
                };
                launcher?: {
                    border?: boolean;
                    color?: string;
                    bg?: string;
                    hover_bg?: string;
                };
            };
            direct?: {
                bg?: string;
                routes?: {
                    list_users?: string;
                    get_user?: string;
                };
            };
        };
    };
}

declare class AnalyzeeHotLeads {
    /**
     * @private Analyzee instance
     */
    private _analyzee;
    /**
     * @private Add event to the queue
     */
    private readonly _addInternalEvent;
    /**
     * @private Options for the session replay
     */
    private _options;
    /**
     * @private Last HotLeads click event
     */
    private _lastClickEvent;
    /**
     * @private WebSocket connection
     */
    private _websocket;
    /**
     * @private setInterval instance for the hot leads predictions
     */
    private _hotLeadsPredictionInterval;
    constructor(analyzee: Analyzee, _addInternalEvent: Analyzee['_addInternalEvent'], options: AnalyzeeSDKOptions['hotLeads'], websocket: WebSocket);
    showDiscount(options: {
        percent: number;
        code: string;
        title: string;
        description: string;
    }): void;
    destroy(): void;
    private _init;
}

declare class AnalyzeeChat {
    /**
     * @private Analyzee instance
     */
    private _analyzee;
    /**
     * @private Add event to the queue
     */
    private readonly _addInternalEvent;
    /**
     * @private Options for the session replay
     */
    private _options;
    /**
     * @private Project ID
     */
    private readonly _project;
    /**
     * @private Analyzee anonymous ID
     */
    private _sender_id;
    constructor(analyzee: Analyzee, _addInternalEvent: Analyzee['_addInternalEvent'], options: AnalyzeeSDKOptions['chat'], project: string);
    destroy(): void;
    initMessenger(config: {
        selector: string;
        token: string;
    }): void;
    private _init;
    private setupSenderId;
    private setupAnalyzeeEventListener;
    private removeIframes;
    private resizeEventListener;
    private setupLauncher;
    private setupMessenger;
}

declare class AnalyzeeHeatmaps {
    /**
     * @private Analyzee instance
     */
    private _analyzee;
    /**
     * @private Analyzee options
     */
    private readonly _config;
    private readonly log;
    private loadingElement;
    private tooltipElement;
    private canvasElement;
    private box;
    private lastHoveredElement;
    private heatmapInstance;
    private aggregatedClicks;
    private elementPositions;
    private totalClicks;
    constructor(analyzee: Analyzee, options: SDKConfig, log: Analyzee['extends']['logger']['log']);
    destroy(): void;
    startLoading(): void;
    endLoading(): void;
    buildCanvasElement(): void;
    initHeatmaps(): void;
    renderTooltip(selector?: string): void;
    renderHeatmap(): void;
    calculateClicks(data: {
        selector: string;
    }[]): Record<string, number>;
    calculateTotalClicks(data: {
        selector: string;
    }[]): number;
    private _init;
}

declare class AnalyzeeUtilities {
    analyzee: Analyzee;
    constructor(analyzee: Analyzee);
    /**
     * Get value from the Session Storage
     * @param key - Key to get
     */
    sessionGet(key: string): any;
    /**
     * Set a value in sessionStorage
     * @param key - Key to set
     * @param value - Value to set
     * @param ttl - Time to live in seconds
     */
    sessionSet(key: string, value: any, ttl?: number): void;
    /**
     * Remove a value from sessionStorage
     * @param key - Key to set
     */
    sessionRemove(key: string): void;
    /**
     * Extend the ttl of a sessionStorage value
     * @param key - Key to extend
     * @param ttl - Time to live in seconds
     * @private
     */
    sessionExtend(key: string, ttl: number): void;
    Debounce(func: Function, delay?: number): (...args: any[]) => void;
    init(): Promise<void>;
    destroy(): Promise<void>;
}

declare class AnalyzeeLogger {
    analyzee: Analyzee;
    constructor(analyzee: Analyzee);
    log(message: any, type?: 'success' | 'warning' | 'error' | 'info'): void;
    init(): Promise<void>;
    destroy(): Promise<void>;
}

declare class AnalyzeeAuthentication {
    analyzee: Analyzee;
    /**
     * @description Anonymous UID
     */
    uid: string;
    constructor(analyzee: Analyzee);
    init(): Promise<void>;
    protected _setupUID(): Promise<void>;
    getCustom(key: string): Promise<string>;
    destroy(): Promise<void>;
}

declare type ObjectValues<T> = T[keyof T];
declare const AnalyzeeService: {
    readonly Assist: "assist";
    readonly Chat: "chat";
    readonly HotLeads: "hotleads";
    readonly Heatmaps: "heatmaps";
    readonly Sessions: "sessions";
};
declare type AnalyzeeService = ObjectValues<typeof AnalyzeeService>;

declare class AnalyzeeServices {
    analyzee: Analyzee;
    constructor(analyzee: Analyzee);
    initService(service: AnalyzeeService): void;
    init(): Promise<void>;
    destroy(): Promise<void>;
}

declare class AnalyzeeConnection {
    analyzee: Analyzee;
    /**
     * @protected Timestamp of the session start
     */
    connectionStartedAt: number;
    /**
     * @private setInterval instance of WebSocket ping
     */
    private _pingInterval;
    /**
     * @private setTimeout instance of WebSocket auto reconnect
     */
    private _autoReconnectTimeout;
    /**
     * @private Flag indicating if publishing handler is already active (When active it means intervals are already set for publishing events)
     */
    private _handlePublishActive;
    /**
     * @private setInterval instance of publishing events
     */
    private _handlePublishInterval;
    private _publishActive;
    constructor(analyzee: Analyzee);
    init(): Promise<void>;
    destroy(): Promise<void>;
    private _onOpen;
    private _onMessage;
    private _onClose;
    /**
     * This method is dedicated for deciding when and
     * how often should events be published to server
     */
    private _handlePublish;
    /**
     * Aggregate all events and send them to the server
     */
    private _publish;
}

declare class AnalyzeePixel {
    analyzee: Analyzee;
    /**
     * Call this method to add a max scroll event
     */
    private _debounceAddMaxScrollEvent;
    private _maxScrollPercent;
    private _eventListeners;
    private _resizeObserver;
    constructor(analyzee: Analyzee);
    init(): Promise<void>;
    destroy(): Promise<void>;
    private _handleNavigationChange;
    private _scrollListener;
    private _resizeListener;
    private _getDocumentHeight;
    private _setupDebounceAddMaxScrollEvent;
}

interface URLObject {
    hash: string;
    host: string;
    hostname: string;
    href: string;
    origin: string;
    password: string;
    pathname: string;
    port: string;
    protocol: string;
    search: string;
    username: string;
}

declare enum AnalyzeeEventType {
    Navigation = "navigation",
    Track = "track",
    Identify = "identify",
    Click = "click",
    SessionReplay = "session-replay",
    MaxScroll = "max-scroll",
    HotLeads = "hot-leads",
    Console = "console",
    Tag = "tag",
    VisibilityChange = "visibility-change",
    NetworkRequest = "network-request",
    Transaction = "transaction"
}
interface AnalyzeeEventInterface {
    type: AnalyzeeEventType;
    timestamp: number;
    location: URLObject;
    source: 'sdk' | 'support';
    payload?: any;
}
interface SessionReplayEvent {
    [key: string]: any;
}
/**
 * @description Event fired on page navigation
 */
interface AnalyzeeNavigationEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.Navigation;
}
/**
 * @description Event fired on call of SDK Analyzee.track()
 */
interface AnalyzeeTrackEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.Track;
    payload: {
        label: string;
        data?: any;
    };
}
/**
 * @description Event fired on call of SDK Analyzee.identify()
 */
interface AnalyzeeIdentifyEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.Identify;
    payload: {
        userId: string;
        data?: {
            email?: string;
            firstName?: string;
            lastName?: string;
            company?: string;
            phone?: string;
            photo?: string;
        };
        metadata?: Record<string, any>;
    };
}
/**
 * @description Event fired on every click on page
 */
interface AnalyzeeClickEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.Click;
    payload: {
        /**
         * @description CSS selector of clicked element
         */
        selector: string;
        /**
         * @description Tag name of clicked element
         */
        tag: string;
        /**
         * @description Text content of clicked element
         */
        content: string;
        /**
         * @description Global coordinates of click relative to the document
         */
        global: {
            x: number;
            y: number;
        };
        /**
         * @description Coordinates of click relative to the clicked element
         */
        relative: {
            x: number;
            y: number;
        };
        /**
         * @description Flag indicating click was dead (did not lead to any action)
         */
        dead: boolean;
    };
}
/**
 * @description Event fired by library 'rrweb'.
 * Used for displaying video of session
 */
interface AnalyzeeSessionReplayEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.SessionReplay;
    payload: SessionReplayEvent;
}
interface AnalyzeeMaxScrollEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.MaxScroll;
    payload: {
        /**
         * @description Percentage of scroll relative to the document
         * @range (0 - 100)
         */
        percentage: number;
        /**
         * @description Height of document in pixels
         */
        documentHeight: number;
    };
}
interface AnalyzeeHotLeadsEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.HotLeads;
    payload: {
        clicks: number;
        adClick: boolean;
        browser: string;
        day: number;
        device: string;
        duration: number;
        country: string;
        hours: number;
        platform: string;
        scrolled: number;
    };
}
interface AnalyzeeConsoleEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.Console;
    payload: {
        type: 6;
        data: {
            plugin: 'rrweb/console@1';
            payload: {
                level: 'log' | 'warn' | 'error' | 'info';
                trace: string[];
                payload: any;
            };
        };
        timestamp: number;
    };
}
interface AnalyzeeTagEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.Tag;
    payload: {
        tag: string;
    };
}
interface AnalyzeeVisibilityChangeEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.VisibilityChange;
    payload: {
        state: 'visible' | 'hidden';
    };
}
interface AnalyzeeNetworkRequestEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.NetworkRequest;
    payload: {
        url: string;
        initiatorType: 'audio' | 'beacon' | 'body' | 'css' | 'early-hint' | 'embed' | 'fetch' | 'frame' | 'iframe' | 'icon' | 'image' | 'img' | 'input' | 'link' | 'navigation' | 'object' | 'ping' | 'script' | 'track' | 'video' | 'xmlhttprequest';
        status: number;
        startTime: number;
        endTime: number;
        method: 'GET' | 'POST' | 'PUT' | 'DELETE' | 'PATCH' | 'OPTIONS' | 'HEAD' | 'TRACE' | 'CONNECT';
        requestHeaders: Record<string, string>;
        requestBody: any;
        responseHeaders: Record<string, string>;
        responseBody: any;
    };
}
interface AnalyzeeTransactionEvent extends AnalyzeeEventInterface {
    type: AnalyzeeEventType.Transaction;
    payload: {
        id: string;
        revenue: number;
        affiliation?: string;
        shipping?: number;
        tax?: number;
        currency?: string;
        items?: {
            id: string;
            name: string;
            price: number;
            quantity: number;
            category?: string;
        }[];
    };
}
declare type AnalyzeeEvent = AnalyzeeNavigationEvent | AnalyzeeTrackEvent | AnalyzeeIdentifyEvent | AnalyzeeClickEvent | AnalyzeeSessionReplayEvent | AnalyzeeMaxScrollEvent | AnalyzeeHotLeadsEvent | AnalyzeeConsoleEvent | AnalyzeeTagEvent | AnalyzeeVisibilityChangeEvent | AnalyzeeNetworkRequestEvent | AnalyzeeTransactionEvent;

/**
 * Services
 */

declare type AnalyzeeWebSocket = WebSocket & {
    connected?: boolean;
};
declare global {
    interface Window {
        analyzee: Analyzee;
    }
}
declare class Analyzee {
    /**
     * @description Session ID
     */
    session: string;
    /**
     * @description Configuration policies
     */
    config: SDKConfig;
    /**
     * @description Array of events to be sent to the server
     */
    events: AnalyzeeEvent[];
    services: {
        [AnalyzeeService.Assist]?: AnalyzeeAssist;
        [AnalyzeeService.Chat]?: AnalyzeeChat;
        [AnalyzeeService.HotLeads]?: AnalyzeeHotLeads;
        [AnalyzeeService.Heatmaps]?: AnalyzeeHeatmaps;
        [AnalyzeeService.Sessions]?: AnalyzeeSessions;
    };
    /**
     * WebSocket connection
     */
    websocket: AnalyzeeWebSocket;
    extends: {
        utilities: AnalyzeeUtilities;
        logger: AnalyzeeLogger;
        authentication: AnalyzeeAuthentication;
        services: AnalyzeeServices;
        connection: AnalyzeeConnection;
        pixel: AnalyzeePixel;
    };
    private _eventListeners;
    /**
     * @private setInterval instance of updating latest ping
     */
    private _updateLatestPingInterval;
    constructor(config: SDKConfig);
    /**
     * Public methods
     */
    addEventListener(event: 'event', callback: (event: AnalyzeeEvent) => void): void;
    removeEventListener(event: 'event', callback: (event: AnalyzeeEvent) => void): void;
    _addInternalEvent(payload: Partial<AnalyzeeEvent>): void;
    /**
     * Track any actions your users perform,
     * along with data that describes the action
     * @param event - The name of the event you’re tracking
     * @param data - A dictionary of data that describes the event
     */
    addEvent(event: string, data?: {
        [key: string]: any;
    }): void;
    /**
     * @deprecated Use the addEvent method to track any actions your users perform
     *
     * Track any actions your users perform,
     * along with data that describes the action
     * @param event - The name of the event you’re tracking
     * @param data - A dictionary of data that describes the event
     */
    track(event: string, data?: {
        [key: string]: any;
    }): void;
    /**
     * Add a transaction to the current session
     * @param transaction - The transaction object
     * @param transaction.id - The transaction ID (required)
     * @param transaction.revenue - The revenue of the transaction (required)
     * @param transaction.affiliation - The store or affiliation from which this transaction occurred
     * @param transaction.shipping - The shipping cost
     * @param transaction.tax - The tax amount
     * @param transaction.currency - The currency of the transaction
     * @param transaction.items - The items in the transaction
     * @param transaction.items.id - The item ID
     * @param transaction.items.name - The item name
     * @param transaction.items.price - The item price
     * @param transaction.items.quantity - The item quantity
     * @param transaction.items.category - The item category
     */
    addTransaction(transaction: {
        id: string;
        revenue: number;
        affiliation?: string;
        shipping?: number;
        tax?: number;
        currency?: string;
        items?: {
            id: string;
            name: string;
            price: number;
            quantity: number;
            category?: string;
        }[];
    }): void;
    /**
     * Add a tag to the current session
     * @param tag - The name of the tag
     */
    addTag(tag: string): void;
    /**
     * Use the addUser method to link your users and their actions
     * to a recognizable userId and metadata.
     * @param id - User ID
     * @param data - Information you know about the user, like their firstName, lastName, email, company, etc.
     * @param metadata - Any other information you want to store about the user
     */
    addUser(id: string, data?: {
        email?: string;
        firstName?: string;
        lastName?: string;
        company?: string;
        phone?: string;
        photo?: string;
    }, metadata?: {
        [key: string]: any;
    }): void;
    /**
     * @deprecated Use the addUser method to link your users and their actions
     *
     * Use the identify method to link your users and their actions
     * to a recognizable userId and metadata.
     * @param id - User ID
     * @param data - Information you know about the user, like id or name
     */
    identify(id: string, data?: {
        [key: string]: any;
    }): void;
    destroy(): Promise<void>;
    /**
     * Hides the chat launcher
     */
    hideChat(): void;
    /**
     * Shows the chat launcher
     */
    showChat(): void;
    private _init;
    private _updateLatestPing;
}

export { Analyzee as default };
