import { Dexie } from 'dexie';
import { randomString } from '../utils/random';
import { messageLauncher } from '../utils/message-launcher';
import { AnalyzeeEventType } from './../shared/interfaces/analyzee-event.interface';
import { environment } from '../utils/environment';
export class AnalyzeeChat {
    // private _called = false;
    constructor(analyzee, _addInternalEvent, options, project) {
        this._analyzee = analyzee;
        this._addInternalEvent = _addInternalEvent;
        this._options = options;
        this._project = project;
        this._init();
    }
    destroy() {
        const chatLauncherIframe = document.getElementById('analyzee-chat-launcher');
        const chatMessengerIframe = document.getElementById('analyzee-chat-popup');
        const chatDirectIframe = document.getElementById('analyzee-chat-direct');
        if (chatLauncherIframe) {
            chatLauncherIframe.remove();
        }
        if (chatMessengerIframe) {
            chatMessengerIframe.remove();
        }
        if (chatDirectIframe) {
            chatDirectIframe.remove();
        }
        window.removeEventListener('resize', this.resizeEventListener, { passive: true });
    }
    initMessenger(config) {
        if (!(config === null || config === void 0 ? void 0 : config.token) || !(config === null || config === void 0 ? void 0 : config.selector) || !this._options.direct) {
            return;
        }
        const iframe = document.createElement('iframe');
        iframe.id = 'analyzee-chat-direct';
        iframe.src = `${environment.chat.url}/?mode=direct_chat&token=${config.token}&project=${this._project}`;
        iframe.style.width = '100%';
        iframe.style.height = '100%';
        iframe.style.border = 'none';
        const element = document.querySelector(config.selector);
        if (!element) {
            return;
        }
        element.appendChild(iframe);
    }
    _init() {
        this.setupAnalyzeeEventListener();
        if (this._options.support) {
            this.setupSenderId().then(() => {
                this.setupLauncher();
                this.setupMessenger();
            });
        }
    }
    setupSenderId() {
        const db = new Dexie('analyzee');
        return new Promise((resolve) => {
            db.version(1).stores({
                analyzee: 'id',
            });
            db.analyzee.get('email').then((result) => {
                if (result === null || result === void 0 ? void 0 : result.value) {
                    this._sender_id = result === null || result === void 0 ? void 0 : result.value;
                    resolve();
                }
                db.analyzee.get('uid').then((result) => {
                    this._sender_id =
                        (result === null || result === void 0 ? void 0 : result.value) ||
                            `an-chat-${randomString(8)}-${randomString(8)}-${randomString(8)}-${randomString(8)}`;
                    resolve();
                });
            });
        });
    }
    setupAnalyzeeEventListener() {
        window.addEventListener('message', (event) => {
            if (event.data.action === 'analyzee:chat:identify') {
                const identify = event.data.payload;
                const email = identify.userId;
                if (!email) {
                    return;
                }
                this._addInternalEvent({
                    type: AnalyzeeEventType.Identify,
                    payload: {
                        userId: email
                    },
                });
                const db = new Dexie('analyzee');
                db.version(1).stores({
                    analyzee: 'id',
                });
                db.analyzee.get('email').then((result) => {
                    if ((result === null || result === void 0 ? void 0 : result.value) === email) {
                        return;
                    }
                    db.analyzee.put({
                        id: 'email',
                        value: email,
                    });
                    this._sender_id = email;
                    return;
                });
            }
            if (event.data.action === 'analyzee:logout') {
                const db = new Dexie('analyzee');
                db.version(1).stores({
                    analyzee: 'id',
                });
                db.analyzee.get('email').then((result) => {
                    if (!(result === null || result === void 0 ? void 0 : result.value)) {
                        return;
                    }
                    db.analyzee.get('uid').then((result) => {
                        if (!(result === null || result === void 0 ? void 0 : result.value)) {
                            return;
                        }
                        this._sender_id = result === null || result === void 0 ? void 0 : result.value;
                        this.removeIframes();
                        this.setupLauncher();
                        this.setupMessenger();
                        db.analyzee.delete('email');
                    });
                });
            }
            if (event.data.action === 'analyzee:launcher:ready') {
                messageLauncher();
            }
        });
    }
    removeIframes() {
        const chatLauncherIframe = document.getElementById('analyzee-chat-launcher');
        const chatMessengerIframe = document.getElementById('analyzee-chat-popup');
        if (chatLauncherIframe) {
            chatLauncherIframe.remove();
        }
        if (chatMessengerIframe) {
            chatMessengerIframe.remove();
        }
    }
    resizeEventListener() {
        const iframe = document.getElementById('analyzee-chat-popup');
        if (!iframe) {
            return;
        }
        iframe === null || iframe === void 0 ? void 0 : iframe.contentWindow.postMessage({
            action: 'analyzee:resize',
            payload: {
                width: window.innerWidth
            }
        }, '*');
    }
    setupLauncher() {
        const chatLauncherIframe = document.getElementById('analyzee-chat-launcher');
        if (chatLauncherIframe) {
            return;
        }
        const src = `${environment.chat.url}/?mode=launcher&project=${this._project}&sender_id=${this._sender_id}&title=${document.title}&url=${window.location.href}`;
        const iframe = document.createElement('iframe');
        iframe.id = 'analyzee-chat-launcher';
        iframe.src = src;
        iframe.style.border = 'none';
        document.body.appendChild(iframe);
        const style = document.createElement('style');
        style.innerHTML = `
      #analyzee-chat-launcher {
        position: fixed;
        bottom: 15px;
        right: 15px;
        width: 60px;
        height: 60px;
        z-index: 999999999999;
        transition: all 0.3s ease-in-out;
        background-color: transparent !important;
        // background-color: red !important;
        overscroll-behavior: contain;
      }

      @media (max-width: 600px) {
        #analyzee-chat-launcher {
          z-index: 899999999999;
        }
      }
    `;
        document.head.appendChild(style);
    }
    setupMessenger() {
        const chatMessengerIframe = document.getElementById('analyzee-chat-popup');
        if (chatMessengerIframe) {
            return;
        }
        const src = `${environment.chat.url}/?mode=popup&project=${this._project}&sender_id=${this._sender_id}&width=${window.innerWidth}`;
        const iframe = document.createElement('iframe');
        iframe.id = 'analyzee-chat-popup';
        iframe.src = src;
        iframe.style.border = 'none';
        document.body.appendChild(iframe);
        const style = document.createElement('style');
        style.innerHTML = `
      #analyzee-chat-popup {
        z-index: 999999999999;
        position: fixed;
        bottom: 84px;
        right: 16px;
        width: 0;
        height: 0;
        min-height: 0;
        max-height: 0;
        box-shadow: 0;
        border-radius: 16px;
        overflow: hidden;
        transform-origin: right bottom;
        transition: width 200ms ease 150ms, height 200ms ease 150ms, max-height 200ms ease 150ms, transform 300ms cubic-bezier(0, 1.2, 1, 1) 150ms, opacity ease 150ms, box-shadow ease 150ms;
        pointer-events: none;
        overscroll-behavior: contain;
      }
      
      #analyzee-chat-popup.open {
        height: min(704px, 100% - 104px);
        min-height: 80px;
        width: 380px;
        max-height: 704px;
        pointer-events: all;
        box-shadow: rgba(0, 0, 0, 0.16) 0px 5px 40px;
        overscroll-behavior: contain;
      }
      
      @media (max-width: 600px) {
        #analyzee-chat-popup {
          bottom: 0;
          right: 0;
          border-radius: 0;
        }
      
        #analyzee-chat-popup.open {
          width: 100% !important;
          height: 100% !important;
          max-height: 100% !important;
          min-height: 100% !important;
          top: 0;
        }
      }
    `;
        document.head.appendChild(style);
        this.resizeEventListener();
        window.addEventListener('message', (event) => {
            if (event.data.action === 'messenger') {
                const payload = event.data.payload;
                if (payload.status) {
                    iframe.classList.add('open');
                }
                else {
                    iframe.classList.remove('open');
                }
            }
        });
        window.addEventListener('resize', this.resizeEventListener, { passive: true });
        // Simulate identify event
        // if (!this._called) {
        //   setTimeout(() => {
        //     this.addEvent({
        //       type: 'identify' as any,
        //       payload: {
        //         userId: 'dakizavo@gmail.com',
        //       }
        //     });
        //     this._called = true;
        //   }, 5000);
        // }
    }
}
